==> owncloud-9.0.3.tgz: owncloud/core/l10n/eo.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Ne eblis mesaĝi al jenaj uzantoj: %s",
    "Updated database" : "Ĝisdatiĝis datumbazo",
    "Updated \"%s\" to %s" : "Ĝisdatiĝis “%s” al %s",
    "%s (incompatible)" : "%s (nekongrua)",
    "Following apps have been disabled: %s" : "Jenaj aplikaĵoj malkapablas: %s",
    "Please select a file." : "Bonvolu elekti dosieron.",
    "File is too big" : "Dosiero tro grandas.",
    "Unknown filetype" : "Ne konatas dosiertipo",
    "Invalid image" : "Ne validas bildo",
    "Sunday" : "dimanĉo",
    "Monday" : "lundo",
    "Tuesday" : "mardo",
    "Wednesday" : "merkredo",
    "Thursday" : "ĵaŭdo",
    "Friday" : "vendredo",
    "Saturday" : "sabato",
    "Sun." : "dim.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mer.",
    "Thu." : "ĵaŭ.",
    "Fri." : "ven.",
    "Sat." : "sab.",
    "Su" : "Di",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Ĵa",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "Januaro",
    "February" : "Februaro",
    "March" : "Marto",
    "April" : "Aprilo",
    "May" : "Majo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Aŭgusto",
    "September" : "Septembro",
    "October" : "Oktobro",
    "November" : "Novembro",
    "December" : "Decembro",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aŭg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Agordo",
    "Saving..." : "Konservante...",
    "seconds ago" : "sekundoj antaŭe",
    "I know what I'm doing" : "mi scias, kion mi faras",
    "No" : "Ne",
    "Yes" : "Jes",
    "Choose" : "Elekti",
    "Ok" : "Akcepti",
    "Error loading message template: {error}" : "Eraris ŝargo de mesaĝa ŝablono: {eraro}",
    "read-only" : "nurlega",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
    "One file conflict" : "Unu dosierkonflikto",
    "New Files" : "Novaj dosieroj",
    "Already existing files" : "Jam ekzistantaj dosieroj",
    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
    "Cancel" : "Nuligi",
    "Continue" : "Daŭri",
    "(all selected)" : "(ĉiuj elektitas)",
    "({count} selected)" : "({count} elektitas)",
    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Error occurred while checking server setup" : "Eraris kontrolo de servila agordo",
    "Shared" : "Kunhavata",
    "Shared with {recipients}" : "Kunhavata kun {recipients}",
    "Error" : "Eraro",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Error while unsharing" : "Eraro dum malkunhavigo",
    "Error setting expiration date" : "Eraro dum agordado de limdato",
    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Sending ..." : "Sendante...",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Share link" : "Konhavigi ligilon",
    "Link" : "Ligilo",
    "Password protect" : "Protekti per pasvorto",
    "Password" : "Pasvorto",
    "Allow editing" : "Permesi redakton",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Send" : "Sendi",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "group" : "grupo",
    "remote" : "fora",
    "notify by email" : "avizi per retpoŝto",
    "Unshare" : "Malkunhavigi",
    "can share" : "kunhavebla",
    "can edit" : "povas redakti",
    "create" : "krei",
    "change" : "ŝanĝi",
    "delete" : "forigi",
    "access control" : "alirkontrolo",
    "Could not unshare" : "Ne malkunhaveblas",
    "Share details could not be loaded for this item." : "Kunhavaj detaloj ne ŝargeblis por ĉi tiu ero.",
    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
    "An error occured. Please try again" : "Eraro okazis, Bonvolu provi ree.",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (at {server})" : "{sharee} (ĉe {server})",
    "{sharee} (remote)" : "{sharee} (fora)",
    "Share" : "Kunhavigi",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Kunhaviki kun homoj en aliaj ownCloud-oj uzante la sintakson uzantonomo@ekzemplo.com/owncloud",
    "Share with users or groups …" : "Kunhavigi kun uzantoj aŭ grupoj..",
    "Share with users, groups or remote users …" : "Kunhavigi kun uzantoj, grupoj aŭ foraj uzantoj...",
    "Error removing share" : "Eraris forigo de kunhavigo",
    "Warning" : "Averto",
    "Error while sending notification" : "Eraris sendo de sciigo",
    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
    "not assignable" : "neatribuebla",
    "invisible" : "nevidebla",
    "({scope})" : "({scope})",
    "Delete" : "Forigi",
    "Rename" : "Alinomigi",
    "The object type is not specified." : "Ne indikiĝis tipo de la objekto.",
    "Enter new" : "Enigu novan",
    "Add" : "Aldoni",
    "Edit tags" : "Redakti etikedojn",
    "Error loading dialog template: {error}" : "Eraris ŝargo de dialoga ŝablono: {error}",
    "No tags selected for deletion." : "Neniu etikedo elektitas por forigo.",
    "unknown text" : "nekonata teksto",
    "Hello world!" : "Saluton, mondo!",
    "Hello {name}, the weather is {weather}" : "Saluton, {name}, la vetero estas {weather}",
    "Hello {name}" : "Saluton, {name}",
    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
    "An error occurred." : "Eraro okazis.",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "The update was unsuccessful. " : "La ĝisdatigo malsukcesis.",
    "The update was successful. There were warnings." : "La ĝisdatigo sukcesis. Estis avertoj.",
    "The update was successful. Redirecting you to ownCloud now." : "La ĝisdatigo estis sukcesa. Alidirektante nun al ownCloud.",
    "Searching other places" : "Serĉante en aliaj lokoj",
    "No search results in other folders" : "Neniu serĉorezulto en aliaj dosierujoj",
    "Personal" : "Persona",
    "Users" : "Uzantoj",
    "Apps" : "Aplikaĵoj",
    "Admin" : "Administranto",
    "Help" : "Helpo",
    "Error loading tags" : "Eraris ŝargo de etikedoj",
    "Tag already exists" : "La etikedo jam ekzistas",
    "Error deleting tag(s)" : "Eraris forigo de etikedo(j)",
    "Error tagging" : "Eraris etikedado",
    "Error untagging" : "Eraris maletikedado",
    "Error favoriting" : "Eraris pliŝatomarko",
    "Error unfavoriting" : "Eraris pliŝatomalmarko",
    "Access forbidden" : "Aliro estas malpermesata",
    "File not found" : "Dosiero ne troviĝis",
    "The share will expire on %s." : "La kunhavo senvalidiĝos je %s.",
    "More details can be found in the server log." : "Pli da detaloj troveblas en la servila protokolo.",
    "Technical details" : "Teĥnikaj detaloj",
    "Remote Address: %s" : "Fora adreso: %s",
    "Request ID: %s" : "Peta identigilo: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Kodo: %s",
    "Message: %s" : "Mesaĝo: %s",
    "File: %s" : "Dosiero: %s",
    "Line: %s" : "Linio: %s",
    "Security warning" : "Sekureca averto",
    "Create an <strong>admin account</strong>" : "Krei <strong>administran konton</strong>",
    "Username" : "Uzantonomo",
    "Storage & database" : "Memoro kaj datumbazo",
    "Data folder" : "Datuma dosierujo",
    "Configure the database" : "Agordi la datumbazon",
    "Only %s is available." : "Nur %s disponeblas.",
    "Database user" : "Datumbaza uzanto",
    "Database password" : "Datumbaza pasvorto",
    "Database name" : "Datumbaza nomo",
    "Database tablespace" : "Datumbaza tabelospaco",
    "Database host" : "Datumbaza gastigo",
    "SQLite will be used as database." : "SQLite uziĝos kiel datumbazo.",
    "For larger installations we recommend to choose a different database backend." : "Por pli grandaj instaloj ni rekomendas elekti malsaman datumbazomotoron.",
    "Finish setup" : "Fini la instalon",
    "Finishing …" : "Finante...",
    "Need help?" : "Ĉu necesas helpo?",
    "See the documentation" : "Vidi la dokumentaron",
    "Log out" : "Elsaluti",
    "Search" : "Serĉi",
    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
    "An internal error occured." : "Ena eraro okazis.",
    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
    "Log in" : "Ensaluti",
    "Wrong password." : "Malĝusta pasvorto.",
    "Stay logged in" : "Daŭri ensalutinta",
    "Alternative Logins" : "Alternativaj ensalutoj",
    "Use the following link to reset your password: {link}" : "Uzu la jenan ligilon por restarigi vian pasvorton: {link}",
    "New password" : "Nova pasvorto",
    "New Password" : "Nova pasvorto",
    "Reset password" : "Rekomenci la pasvorton",
    "Thank you for your patience." : "Dankon pro via pacienco.",
    "%s will be updated to version %s" : "%s ĝisdatiĝos al eldono %s",
    "These apps will be updated:" : "Ĉi tiuj aplikaĵoj ĝisdatiĝos:",
    "These incompatible apps will be disabled:" : "Ĉi tiuj malkongruaj aplikaĵoj malkapabliĝos:",
    "Start update" : "Ekĝisdatigi",
    "Error loading message template: {error}" : "Eraris ŝargo de mesaĝa ŝablono: {eraro}"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/core/l10n/eo.js <==
OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bonvolu elekti dosieron.",
    "File is too big" : "Dosiero tro grandas.",
    "Unknown filetype" : "Ne konatas dosiertipo",
    "Invalid image" : "Ne validas bildo",
    "Couldn't send mail to following users: %s " : "Ne eblis mesaĝi al jenaj uzantoj: %s",
    "Updated database" : "Ĝisdatiĝis datumbazo",
    "Updated \"%s\" to %s" : "Ĝisdatiĝis “%s” al %s",
    "%s (incompatible)" : "%s (nekongrua)",
    "Following apps have been disabled: %s" : "Jenaj aplikaĵoj malkapablas: %s",
    "Sunday" : "dimanĉo",
    "Monday" : "lundo",
    "Tuesday" : "mardo",
    "Wednesday" : "merkredo",
    "Thursday" : "ĵaŭdo",
    "Friday" : "vendredo",
    "Saturday" : "sabato",
    "Sun." : "dim.",
    "Mon." : "lun.",
    "Tue." : "mar.",
    "Wed." : "mer.",
    "Thu." : "ĵaŭ.",
    "Fri." : "ven.",
    "Sat." : "sab.",
    "Su" : "Di",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Me",
    "Th" : "Ĵa",
    "Fr" : "Ve",
    "Sa" : "Sa",
    "January" : "Januaro",
    "February" : "Februaro",
    "March" : "Marto",
    "April" : "Aprilo",
    "May" : "Majo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Aŭgusto",
    "September" : "Septembro",
    "October" : "Oktobro",
    "November" : "Novembro",
    "December" : "Decembro",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aŭg.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Agordo",
    "Saving..." : "Konservante...",
    "seconds ago" : "sekundoj antaŭe",
    "I know what I'm doing" : "mi scias, kion mi faras",
    "No" : "Ne",
    "Yes" : "Jes",
    "Choose" : "Elekti",
    "Ok" : "Akcepti",
    "Error loading message template: {error}" : "Eraris ŝargo de mesaĝa ŝablono: {eraro}",
    "read-only" : "nurlega",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosierkonflikto","{count} dosierkonfliktoj"],
    "One file conflict" : "Unu dosierkonflikto",
    "New Files" : "Novaj dosieroj",
    "Already existing files" : "Jam ekzistantaj dosieroj",
    "Which files do you want to keep?" : "Kiujn dosierojn vi volas konservi?",
    "If you select both versions, the copied file will have a number added to its name." : "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
    "Cancel" : "Nuligi",
    "Continue" : "Daŭri",
    "(all selected)" : "(ĉiuj elektitas)",
    "({count} selected)" : "({count} elektitas)",
    "Error loading file exists template" : "Eraris ŝargo de ŝablono pri ekzistanta dosiero",
    "Very weak password" : "Tre malforta pasvorto",
    "Weak password" : "Malforta pasvorto",
    "So-so password" : "Mezaĉa pasvorto",
    "Good password" : "Bona pasvorto",
    "Strong password" : "Forta pasvorto",
    "Error occurred while checking server setup" : "Eraris kontrolo de servila agordo",
    "Shared" : "Kunhavata",
    "Shared with {recipients}" : "Kunhavata kun {recipients}",
    "Error" : "Eraro",
    "Error while sharing" : "Eraro dum kunhavigo",
    "Error while unsharing" : "Eraro dum malkunhavigo",
    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
    "Set expiration date" : "Agordi limdaton",
    "Expiration" : "Eksvalidiĝo",
    "Expiration date" : "Limdato",
    "Link" : "Ligilo",
    "Edit" : "Redakti",
    "Remove" : "Forigi",
    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
    "Filename" : "Dosiernomo",
    "Password" : "Pasvorto",
    "Name" : "Nomo",
    "Allow editing" : "Permesi redakton",
    "Save" : "Konservi",
    "Error while sending notification" : "Eraris sendo de sciigo",
    "Sending ..." : "Sendante...",
    "Email sent" : "La retpoŝtaĵo sendiĝis",
    "Email link to person" : "Retpoŝti la ligilon al ulo",
    "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
    "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
    "group" : "grupo",
    "remote" : "fora",
    "notify by email" : "avizi per retpoŝto",
    "Unshare" : "Malkunhavigi",
    "can share" : "kunhavebla",
    "can edit" : "povas redakti",
    "create" : "krei",
    "change" : "ŝanĝi",
    "delete" : "forigi",
    "access control" : "alirkontrolo",
    "Could not unshare" : "Ne malkunhaveblas",
    "Share details could not be loaded for this item." : "Kunhavaj detaloj ne ŝargeblis por ĉi tiu ero.",
    "No users or groups found for {search}" : "Neniu uzanto aŭ grupo troviĝis por {search}",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (at {server})" : "{sharee} (ĉe {server})",
    "{sharee} (remote)" : "{sharee} (fora)",
    "Share" : "Kunhavigi",
    "Resharing is not allowed" : "Rekunhavigo ne permesatas",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Kunhaviki kun homoj en aliaj ownCloud-oj uzante la sintakson uzantonomo@ekzemplo.com/owncloud",
    "Error removing share" : "Eraris forigo de kunhavigo",
    "Warning" : "Averto",
    "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
    "invisible" : "nevidebla",
    "({scope})" : "({scope})",
    "Delete" : "Forigi",
    "Rename" : "Alinomigi",
    "The object type is not specified." : "Ne indikiĝis tipo de la objekto.",
    "Enter new" : "Enigu novan",
    "Add" : "Aldoni",
    "Edit tags" : "Redakti etikedojn",
    "Error loading dialog template: {error}" : "Eraris ŝargo de dialoga ŝablono: {error}",
    "No tags selected for deletion." : "Neniu etikedo elektitas por forigo.",
    "unknown text" : "nekonata teksto",
    "Hello world!" : "Saluton, mondo!",
    "Hello {name}, the weather is {weather}" : "Saluton, {name}, la vetero estas {weather}",
    "Hello {name}" : "Saluton, {name}",
    "_download %n file_::_download %n files_" : ["elŝuti %n dosieron","elŝuti %n dosierojn"],
    "An error occurred." : "Eraro okazis.",
    "Please reload the page." : "Bonvolu reŝargi la paĝon.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "La ĝisdatigo estis malsukcese. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownClouda komunumo</a>.",
    "The update was successful. There were warnings." : "La ĝisdatigo sukcesis. Estis avertoj.",
    "The update was successful. Redirecting you to ownCloud now." : "La ĝisdatigo estis sukcesa. Alidirektante nun al ownCloud.",
    "Searching other places" : "Serĉante en aliaj lokoj",
    "No search results in other folders" : "Neniu serĉorezulto en aliaj dosierujoj",
    "Personal" : "Persona",
    "Users" : "Uzantoj",
    "Apps" : "Aplikaĵoj",
    "Admin" : "Administranto",
    "Help" : "Helpo",
    "Access forbidden" : "Aliro estas malpermesata",
    "File not found" : "Dosiero ne troviĝis",
    "The share will expire on %s." : "La kunhavo senvalidiĝos je %s.",
    "More details can be found in the server log." : "Pli da detaloj troveblas en la servila protokolo.",
    "Technical details" : "Teĥnikaj detaloj",
    "Remote Address: %s" : "Fora adreso: %s",
    "Request ID: %s" : "Peta identigilo: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Kodo: %s",
    "Message: %s" : "Mesaĝo: %s",
    "File: %s" : "Dosiero: %s",
    "Line: %s" : "Linio: %s",
    "Create an <strong>admin account</strong>" : "Krei <strong>administran konton</strong>",
    "Username" : "Uzantonomo",
    "Storage & database" : "Memoro kaj datumbazo",
    "Data folder" : "Datuma dosierujo",
    "Configure the database" : "Agordi la datumbazon",
    "Only %s is available." : "Nur %s disponeblas.",
    "Database user" : "Datumbaza uzanto",
    "Database password" : "Datumbaza pasvorto",
    "Database name" : "Datumbaza nomo",
    "Database tablespace" : "Datumbaza tabelospaco",
    "Database host" : "Datumbaza gastigo",
    "SQLite will be used as database." : "SQLite uziĝos kiel datumbazo.",
    "For larger installations we recommend to choose a different database backend." : "Por pli grandaj instaloj ni rekomendas elekti malsaman datumbazomotoron.",
    "Finish setup" : "Fini la instalon",
    "Finishing …" : "Finante...",
    "Need help?" : "Ĉu necesas helpo?",
    "See the documentation" : "Vidi la dokumentaron",
    "Log out" : "Elsaluti",
    "Search" : "Serĉi",
    "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
    "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
    "Log in" : "Ensaluti",
    "Wrong password." : "Malĝusta pasvorto.",
    "Stay logged in" : "Daŭri ensalutinta",
    "Alternative Logins" : "Alternativaj ensalutoj",
    "Use the following link to reset your password: {link}" : "Uzu la jenan ligilon por restarigi vian pasvorton: {link}",
    "New password" : "Nova pasvorto",
    "New Password" : "Nova pasvorto",
    "Reset password" : "Rekomenci la pasvorton",
    "Thank you for your patience." : "Dankon pro via pacienco.",
    "%s will be updated to version %s" : "%s ĝisdatiĝos al eldono %s",
    "These apps will be updated:" : "Ĉi tiuj aplikaĵoj ĝisdatiĝos:",
    "Start update" : "Ekĝisdatigi"
},
"nplurals=2; plural=(n != 1);");
